@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Loader;
 # ABSTRACT: Classe de base pour le chargement de notices biblio/autorité
-$Koha::Contrib::Sudoc::Loader::VERSION = '2.19';
+$Koha::Contrib::Sudoc::Loader::VERSION = '2.20';
 use Moose;
 use Modern::Perl;
 use utf8;
@@ -82,7 +82,7 @@ sub BUILD {
     } catch {
         $self->log->warning(
             "Attention : le convertisseur $class est introuvable dans le répertoire 'lib'. " .
-            "Le convertisseur par défaut sera utilisé.\n");
+            "Le convertisseur par défaut sera utilisé.\n") if $class;
         $class = 'Koha::Contrib::Sudoc::Converter';
     };
     $class = $class->new(sudoc => $self->sudoc, log => $self->log);
@@ -140,7 +140,7 @@ Koha::Contrib::Sudoc::Loader - Classe de base pour le chargement de notices bibl
 
 =head1 VERSION
 
-version 2.19
+version 2.20
 
 =head1 AUTHOR
 
